@@ -42,7 +42,8 @@ class Socket:
     async def __aenter__(self) -> 'Socket':
         """Connect to the socket."""
         sockets = ["/var/run/signald/signald.sock",
-                   "$XDG_RUNTIME_DIR/signald/signald.sock"]
+                   "$XDG_RUNTIME_DIR/signald/signald.sock",
+                   "/run/user/1000/signald/signald.sock"]
         if self._socket_path:
             sockets.append(self._socket_path)
 
@@ -67,7 +68,7 @@ class Socket:
             self.log.info(f"Bot attempted to subscribe to +********{self._username[-3:]}")
         return self
 
-    async def __aexit__(self, *excinfo):
+    async def __aexit__(self, *excinfo) -> None:
         """Disconnect from the internal socket."""
         await self.send({"type": "unsubscribe", "account": self._username,
                          "version": "v1"})
